@@ -111,7 +111,7 @@ class SearchUtil(object):
         return False
 
     def checkQueryCountIsGreaterThanZero(
-        self, query, interval=15, retries=4, max_time=120
+            self, query, interval=15, retries=4, max_time=120
     ):
         self.logger.debug("query is %s", query)
         tryNum = 0
@@ -128,6 +128,25 @@ class SearchUtil(object):
                 time.sleep(interval)
         return False
 
+    def deleteEventsFromIndex(self, index_name="*", max_wait_time=120):
+        """
+        Hides events belonging to specified index from SPL Search using ``| delete`` command.
+
+        Args:
+            index_name: Name of the index to delete events from.
+            max_wait_time: Amount of time job can wait to finish.
+        """
+        query = f"search index={index_name} | delete"
+        self.logger.debug("query is %s", query)
+        try:
+            job = self.jobs.create(query)
+            job.wait(max_wait_time)
+            self.logger.info("Successfully deleted old events")
+
+        except Exception as e:
+            self.logger.debug("CAREFUL - Could not delete old events!")
+            self.logger.debug(e)
+
     def checkQueryCountIsZero(self, query, max_time=120):
         self.logger.debug("query is %s", query)
         tryNum = 0
@@ -143,6 +162,25 @@ class SearchUtil(object):
             self.logger.debug("Count of results is > 0, it is:%d", result_count)
             return False, job.get_results()
 
+    def get_search_results(self, query, max_time=120):
+        """
+            Execute a search query
+        Args:
+            query (str): query string for Splunk Search
+            max_time: Amount of time job can wait to finish.
+        Returns:
+            events that match the query
+        """
+
+        self.logger.debug("query is %s", query)
+        try:
+            job = self.jobs.create(query, auto_finalize_ec=120, max_time=max_time)
+            job.wait(max_time)
+            return job.get_results()
+        except Exception as e:
+            self.logger.debug("Errors when executing search!!!")
+            self.logger.debug(e)
+
     def checkQueryFields(
         self,
         query,
@@ -484,7 +522,7 @@ class SearchUtil(object):
                             msg="Error Sized Gap detected with detection search",
                             actual="gapSize=" + str(result["delta"]),
                             expected="no gaps, or at least gaps shorter than "
-                            + str(warningGapSizeLimit),
+                                     + str(warningGapSizeLimit),
                             errors="Error sized gap detected.",
                             level="error",
                         )
@@ -616,7 +654,7 @@ class SearchUtil(object):
         return status
 
     def checkQueryErrorMessage(
-        self, query, expected, namespace="SA-ThreatIntelligence"
+            self, query, expected, namespace="SA-ThreatIntelligence"
     ):
 
         """Check for specific error text from a search.
@@ -658,13 +696,13 @@ class SearchUtil(object):
         return status
 
     def checkQueryFieldValues(
-        self,
-        query,
-        expected_values,  # can be list, set, tuple, or string
-        expectedMinRow=0,
-        interval=15,
-        retries=4,
-        namespace="SA-ThreatIntelligence",
+            self,
+            query,
+            expected_values,  # can be list, set, tuple, or string
+            expectedMinRow=0,
+            interval=15,
+            retries=4,
+            namespace="SA-ThreatIntelligence",
     ):
 
         """Execute a query and check for a matching set (not necessarily
@@ -990,6 +1028,48 @@ class SearchUtil(object):
 
         return status
 
+    def getFieldValuesList(self, query, interval=15, retries=4):
+        """
+        Get list of results from the query. Where each result will be
+        a dictionary. The search job will retry at given interval if 
+        no results found.
+
+        Args:
+            query (str): query to search on Splunk instance
+            interval (int): at what interval each retry should be made
+            retries (int): number of retries to make if no results found
+        """
+
+        tryNum = 0
+        status = False
+
+        while tryNum <= retries and not status:
+            job = self.jobs.create(query, max_time=60)
+            job.wait(240)
+            results = job.get_results(offset=0, count=4000)
+            result_count = len(results)
+            messages = job.get_messages()
+
+            if result_count > 0:
+                for each_result in results:
+                    keys = list(map(str, list(each_result.keys())))
+                    values = list(map(str, list(each_result.values())))
+                    yield dict(list(zip(keys, values)))
+                break
+            else:
+                self.wrapLogOutput(
+                    msg="Zero results from search:",
+                    actual="",
+                    expected="greater than 0",
+                    errors="\n".join(messages),
+                )
+
+            if not status:
+                tryNum += 1
+                time.sleep(interval)
+
+        return status
+
     def checkRemoteSearch(self, query, starts_with=None, max_time=120):
         self.logger.debug("query is %s", query)
         job = self.jobs.create(query, auto_finalize_ec=200, max_time=max_time)
