@@ -160,6 +160,8 @@ class SampleStanza(object):
             metadata.update(count="100")
         if metadata.get("index") is not None and metadata.get("input_type") in ["syslog_tcp", "tcp", "udp"]:
             raise_warning("For input_type '{}', there should be no index set".format(metadata.get("input_type")))
+        if metadata.get("input_type") == "uf_file_monitor":
+            metadata["host"] = metadata.get("host").replace("_", "-").replace(".", "-")
         return metadata
 
     def get_eventmetadata(self):
