@@ -25,7 +25,6 @@ class UpdateEventgen():
         except OSError:
             LOGGER.error("Eventgen.conf not found")
             raise Exception("Eventgen.conf not found")
-            return None
 
     def get_eventgen_stanzas(self):
         """
@@ -117,6 +116,10 @@ class UpdateEventgen():
                 eventgen_dict[stanza_name][data] = (f"<<{data}>> "
                                                     f"{review_comments['metadata']}")
 
+            if eventgen_dict[stanza_name].get("index"):
+                eventgen_dict[stanza_name]["index"] = (f"{eventgen_dict[stanza_name]['index']} "
+                                                       f"{review_comments['metadata']}")
+
             eventgen_dict[stanza_name]['source'] = eventgen_dict[stanza_name].get(
                 'source', f"pytest-splunk-addon:{eventgen_dict[stanza_name]['input_type']}")
 
